@@ -70,7 +70,7 @@ YawpConfigDialog::YawpConfigDialog( KConfigDialog * parent, Yawp::Storage * pSto
 	d->pStorage = pStorage;
 	
 	d->bCityModelChanged = false;
-    d->bCitySettingsChanged = false;
+	d->bCitySettingsChanged = false;
 
 	d->pConfigDlg = parent;
 	d->pWeatherModel = new WeatherServiceModel(pStorage, this);
@@ -305,6 +305,8 @@ YawpConfigDialog::setData( const Yawp::ConfigData * data )
 	//--- THEME PAGE ---
 	//
 	checkBoxCustomTheme->setCheckState( data->bUseCustomTheme ? Qt::Checked : Qt::Unchecked );
+	checkInteractivePanelWeatherIcons->setCheckState( data->bUseInteractivePanelWeatherIcons ? Qt::Checked : Qt::Unchecked );
+	
 	changeThemeState( checkBoxCustomTheme->checkState() );
 
 	comboTheme->setCurrentIndex( d->theme_map.key(data->sBackgroundName) );
@@ -446,6 +448,7 @@ YawpConfigDialog::getData( Yawp::ConfigData * data )
 	data->iPanelForecastDays = comboForecastDays->currentIndex();
 
 	data->bUseCompactPanelLayout = checkCompactPanelLayout->isChecked();
+	data->bUseInteractivePanelWeatherIcons = checkInteractivePanelWeatherIcons->isChecked();
 	data->bUseExtendedTooltip = radioExtendedTooltip->isChecked();
 	data->extendedTooltipOptions = 0;
 	if( checkTooltipSateliteMap->isChecked() )
