@@ -64,28 +64,28 @@ GetCountryCode( const QString & sCountry, QString & sCountryCode, const Yawp::St
 	else
 		sTmpCountry = sCountry;
 	
-	dTracing() << "TmpCountry =" << sTmpCountry;
+//	dTracing() << "TmpCountry =" << sTmpCountry;
 	
 	if( !pStorage->unitedStatesMap()->state(sTmpCountry).isEmpty() )
 	{
-		dTracing() << "found united state for" << sTmpCountry;
 		sCountryCode = "us";
+//		dTracing() << "found united state for" << sTmpCountry;
 	}
 	else if( !pStorage->unitedStatesMap()->stateCode(sTmpCountry).isEmpty() )
 	{
-		dTracing() << "found united state for code" << sTmpCountry;
 		sCountryCode = "us";
+//		dTracing() << "found united state for code" << sTmpCountry;
 	}
 	if( sCountryCode.isEmpty() )
 	{
 		sCountryCode = pStorage->countryMap()->countryCode(sTmpCountry);
-		dTracing() << "checked country code" << sCountryCode;
+//		dTracing() << "checked country code" << sCountryCode;
 	}
 	if( sCountryCode.isEmpty() &&
 		!pStorage->countryMap()->country(sTmpCountry).isEmpty() )
 	{
 		sCountryCode = sTmpCountry.toLower();
-		dTracing() << "checked country" << sCountryCode;
+//		dTracing() << "checked country" << sCountryCode;
 	}
 
 //	dTracing() << sCountry << "->" << sCountryCode;
