@@ -35,9 +35,9 @@
 
 //--- KDE4 ---
 #include <KDateTime>
-#include <KGlobalSettings>
 #include <KTimeZones>
 #include <KSystemTimeZones>
+#include <Plasma/Theme>
 
 #if (KDE_VERSION_MINOR == 3 && KDE_VERSION_RELEASE >= 70) || KDE_VERSION_MINOR == 4
 	#include <KUnitConversion/Value>
@@ -73,6 +73,9 @@ struct WeatherDataProcessor::Private
 	 *  In this cases the function returns false, otherwise true.
 	 */
 	bool checkStringValue( const QString & value ) const;
+	
+	QString createWindShortText(const YawpWeather & weather) const;
+	QString createPressureText(const YawpWeather & weather) const;
 
 	/** Parse a string that contains a float number.
 	 *  Returns FLT_MAX when parsing fails.
@@ -288,8 +291,7 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 
 	//--- Set the sun for all forecast days - this is an accuweather specific key. ---
 	for( int iDay = 1; iDay < cityInfo.days().count(); ++iDay )
-		setForecastSun( *cityInfo.days().at(iDay),
-					    data.value( QString("Forecast Sun %1").arg(iDay) ).toString() );
+		setForecastSun( *cityInfo.days().at(iDay), data.value( QString("Forecast Sun %1").arg(iDay) ).toString() );
 
 	/***  Add the current weather informations to the first day ***
 	*/
@@ -326,8 +328,6 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 		weather.setCurrentIconName( mapConditionIcon( data.value("Condition Icon").toString() ) );
 	if( data.contains("Temperature") )
 		weather.setCurrentTemperature( d->convertTemp(  data.value("Temperature").toString(), fromTempSystem ) );
-	if( data.contains("Wind Speed") )
-		weather.setWindSpeed( d->convertSpeed( data.value("Wind Speed").toString(),  fromSpeedSystem ) );
 	if( data.contains("Dewpoint") )
 		weather.setDewpoint( d->convertTemp( data.value("Dewpoint").toString(), fromDewTempSystem ) );
 	if( data.contains("Visibility") )
@@ -338,9 +338,14 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 	if( d->checkStringValue( sTmp ) )
 		weather.setPressureTendency( sTmp );
 
+	if( data.contains("Wind Speed") )
+		weather.setWindSpeed( d->convertSpeed( data.value("Wind Speed").toString(),  fromSpeedSystem ) );
 	sTmp = data.value("Wind Direction").toString();
 	if( d->checkStringValue( sTmp) )
 		weather.setWindDirection( sTmp );
+	
+	weather.setWindShortText( d->createWindShortText(weather) );
+	weather.setPressureShortText( d->createPressureText(weather) );
 
 	sTmp = data.value("Current Conditions").toString();
 	if( d->checkStringValue( sTmp ) )
@@ -401,6 +406,7 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 				cityInfo.setSatelliteImage( img );
 		}
 	}
+	
 	return true;
 }
 
@@ -553,6 +559,7 @@ WeatherDataProcessor::setForecastExtraValues(
 		weather.setTemperatureRealFeelHigh( d->convertTemp(vForecast.at(6), fromTempSystem) );
 		weather.setTemperatureRealFeelLow(  d->convertTemp(vForecast.at(7), fromTempSystem) );
 
+		weather.setWindShortText( d->createWindShortText(weather) );
 		bReturn = true;
 	}
 	return bReturn;
@@ -612,13 +619,55 @@ WeatherDataProcessor::Private::checkStringValue( const QString & value ) const
 	return true;
 }
 
+QString
+WeatherDataProcessor::Private::createWindShortText(const YawpWeather & weather) const
+{
+	QString sText;
+	if( weather.windSpeed() < SHRT_MAX )
+	{
+		sText.append( QString("%1 %2 ")
+			.arg( weather.windSpeed() )
+			.arg( Utils::GetUnitString( speedSystem ) ) );
+		sText.append( i18nc("Wind direction", weather.windDirection().toUtf8().constData()) );
+	}
+	return sText;
+}
+
+QString
+WeatherDataProcessor::Private::createPressureText(const YawpWeather & weather) const
+{
+	QString sText;
+	if( weather.pressure() < SHRT_MAX )
+	{
+		sText.append( QString("\n%1 %2")
+			.arg( weather.pressure() )
+			.arg( Utils::GetUnitString(pressureSystem) ));
+
+		if( !weather.pressureTendency().isEmpty() )
+		{
+			// Pressure tendency arrow
+			QChar sPressureSymbol;
+			QChar sPressureShort = weather.pressureTendency()[0].toLower();
+			if (sPressureShort == QChar('s'))
+				sPressureSymbol = QChar(0x279C); // steady
+			if (sPressureShort == QChar('r') || sPressureShort == QChar('i'))
+				sPressureSymbol = QChar(0x279A); // rising
+			if (sPressureShort == QChar('f') || sPressureShort == QChar('d') )
+				sPressureSymbol = QChar(0x2798); // falling
+			
+			sText.append( QString(" %1").arg(sPressureSymbol) );
+		}
+	}
+	return sText;
+}
+
 float
 WeatherDataProcessor::Private::parseFloat( const QString & value ) const
 {
 	if( !checkStringValue( value ) )
 		return FLT_MAX;
 
-	bool bOk(false);
+	bool bOk = false;
 	float fValue = value.toFloat( &bOk );
 	if( bOk )
 		return fValue;
@@ -626,8 +675,7 @@ WeatherDataProcessor::Private::parseFloat( const QString & value ) const
 }
 
 short
-WeatherDataProcessor::Private::convertDistance( const QString & value,
-												YAWP_DISTANCE_UNIT fromSystem ) const
+WeatherDataProcessor::Private::convertDistance( const QString & value, YAWP_DISTANCE_UNIT fromSystem ) const
 {
 	float fValue = parseFloat( value );
 	if( fValue == FLT_MAX )
@@ -648,8 +696,7 @@ WeatherDataProcessor::Private::convertDistance( const QString & value,
 }
 
 short
-WeatherDataProcessor::Private::convertPressure( const QString & value,
-												YAWP_PRESSURE_UNIT fromSystem ) const
+WeatherDataProcessor::Private::convertPressure( const QString & value, YAWP_PRESSURE_UNIT fromSystem ) const
 {
 	float fValue = parseFloat( value );
 	if( fValue == FLT_MAX )
@@ -670,8 +717,7 @@ WeatherDataProcessor::Private::convertPressure( const QString & value,
 
 
 short
-WeatherDataProcessor::Private::convertTemp( const QString & value,
-											YAWP_TEMPERATURE_UNIT fromSystem ) const
+WeatherDataProcessor::Private::convertTemp( const QString & value, YAWP_TEMPERATURE_UNIT fromSystem ) const
 {
 	float fValue = parseFloat( value );
 	if( fValue == FLT_MAX )
@@ -692,8 +738,7 @@ WeatherDataProcessor::Private::convertTemp( const QString & value,
 }
 
 short
-WeatherDataProcessor::Private::convertSpeed( const QString & value,
-											 YAWP_SPEED_UNIT fromSystem ) const
+WeatherDataProcessor::Private::convertSpeed( const QString & value, YAWP_SPEED_UNIT fromSystem ) const
 {
 	float fValue = parseFloat( value );
 	if( fValue == FLT_MAX )
@@ -841,7 +886,9 @@ WeatherDataProcessor::Private::initIconMap(const QString & resource)
 void
 WeatherDataProcessor::Private::createPropertyStringList( const YawpDay & day, YawpWeather & weather ) const
 {
-	QFont font( KGlobalSettings::generalFont() );
+	Plasma::Theme * theme = Plasma::Theme::defaultTheme();
+	QFont font = theme->font(Plasma::Theme::DefaultFont);
+
 	font.setBold(false);
 	font.setPixelSize(15);
 	QTextLayout textLayout;
@@ -849,8 +896,8 @@ WeatherDataProcessor::Private::createPropertyStringList( const YawpDay & day, Ya
 	
 	QString sOffsetText(3, QChar(' '));
 	QFontMetrics fm(font);
-	qreal dOffsetWidth( (qreal)fm.width(sOffsetText) );
-
+	qreal dOffsetWidth = (qreal)fm.width(sOffsetText);
+	
 	//  go though all property items that has been specified to show in details area
 	//
 	QList<Yawp::DetailsProperty>::const_iterator itMap = vDetailsProperty.begin();
@@ -869,8 +916,8 @@ WeatherDataProcessor::Private::createPropertyStringList( const YawpDay & day, Ya
 		 */
 		sText.replace('\n', QChar::LineSeparator);
 		textLayout.setText( sText );
-		QSizeF textSize = doTextLayout( textLayout, MAX_PROPERTY_TEXT_WIDTH, dOffsetWidth);
-
+		doTextLayout( textLayout, MAX_PROPERTY_TEXT_WIDTH, dOffsetWidth);
+		
 		/*   Add the propery text lines for current property to property-text-line-list
 		 */
 		for( int iLine = 0; iLine < textLayout.lineCount(); iLine++ )
@@ -881,7 +928,7 @@ WeatherDataProcessor::Private::createPropertyStringList( const YawpDay & day, Ya
 			int iStart = line.textStart();
 			int iWidth = line.textLength();
 
-			QChar::Category category( textLayout.text().at(iStart+iWidth-1).category() );
+			QChar::Category category = textLayout.text().at(iStart+iWidth-1).category();
 			iWidth += (category == QChar::Separator_Line || category == QChar::Separator_Space ? -1 : 0);
 
 			// When text line does not fit we have to trim textline
@@ -1051,7 +1098,6 @@ WeatherDataProcessor::Private::doTextLayout( QTextLayout & textLayout, qreal dMa
 		if (!line.isValid())
 			break;
 
-//		dDebug() << "TextLayout: " << textLayout.lineCount();
 		line.setLineWidth(dMaxWidth - (textLayout.lineCount()<=1 ? 0.0f : dOffset ));
 		line.setPosition(QPointF(0, dHeight));
 		dHeight += line.height();
