@@ -36,8 +36,9 @@ struct YawpWeather::Private
 	QString     sDescription;
 	QString     sUrl;
 
-	QString     sWindDirection;
 	short       iWindSpeed;
+	QString     sWindDirection;
+	QString     sWindShortText;
 	short       iHumidity;
 
 	short       iCurrentTemperature;
@@ -47,8 +48,11 @@ struct YawpWeather::Private
 	short       iTemperatureRealFeelLow;
 
 	short       iDewpoint;
+
 	short       iPressure;
 	QString     sPressureTendency;
+	QString     sPressureShortText;
+	
 	short       iUVIndex;
 	QString     sUVRating;
 	short       iVisibility;
@@ -75,9 +79,12 @@ YawpWeather::clear()
 	d->sCurrIconName.clear();
 	d->sIconName                 = QLatin1String("unknown");
 	d->sDescription.clear();
-	d->sWindDirection.clear();
-	d->iHumidity                 = SHRT_MAX;
+
 	d->iWindSpeed                = SHRT_MAX;
+	d->sWindDirection.clear();
+	d->sWindShortText.clear();
+
+	d->iHumidity                 = SHRT_MAX;
 
 	d->iCurrentTemperature       = SHRT_MAX;
 	d->iTemperatureHigh          = SHRT_MAX;
@@ -88,6 +95,7 @@ YawpWeather::clear()
 	d->iDewpoint                 = SHRT_MAX;
 	d->iPressure                 = SHRT_MAX;
 	d->sPressureTendency.clear();
+	d->sPressureShortText.clear();
 	d->iUVIndex                  = SHRT_MAX;
 	d->sUVRating.clear();
 	d->iVisibility               = SHRT_MAX;
@@ -116,17 +124,23 @@ void
 YawpWeather::setDescription(const QString & desc) { d->sDescription = desc; }
 
 const QString &
-YawpWeather::windDirection() const { return d->sWindDirection; }
+YawpWeather::windShortText() const {return d->sWindShortText;}
 
 void
-YawpWeather::setWindDirection(const QString & direction) { d->sWindDirection = direction; }
+YawpWeather::setWindShortText(const QString& text) { d->sWindShortText = text; }
 
-short
+short int
 YawpWeather::windSpeed() const { return d->iWindSpeed; }
 
 void
 YawpWeather::setWindSpeed(short speed) { d->iWindSpeed = speed; }
 
+const QString &
+YawpWeather::windDirection() const { return d->sWindDirection; }
+
+void
+YawpWeather::setWindDirection(const QString & direction) { d->sWindDirection = direction; }
+
 short
 YawpWeather::humidity() const { return d->iHumidity; }
 
@@ -181,6 +195,12 @@ YawpWeather::pressureTendency() const { return d->sPressureTendency; }
 void
 YawpWeather::setPressureTendency(const QString & sTendency) { d->sPressureTendency = sTendency; }
 
+const QString &
+YawpWeather::pressureShortText() const { return d->sPressureShortText; }
+
+void
+YawpWeather::setPressureShortText(const QString& text) { d->sPressureShortText = text; }
+
 short
 YawpWeather::uvIndex() const { return d->iUVIndex; }
 
@@ -403,11 +423,26 @@ CityWeather::createLocalizedCityString()
 
 QDateTime
 CityWeather::localTime() const
+{
+	return toLocalTime(QDateTime::currentDateTime());
+}
+
+QDateTime
+CityWeather::toLocalTime(const QDateTime & dateTime) const
 {
 	KTimeZone local = KSystemTimeZones::local();
 	if( m_timeZone.isValid() && local.name() != m_timeZone.name() )
-		return KSystemTimeZones::local().convert(m_timeZone, QDateTime::currentDateTime());
-	return QDateTime::currentDateTime();
+		return KSystemTimeZones::local().convert(m_timeZone, dateTime);
+	return dateTime;
+}
+
+QDateTime
+CityWeather::fromLocalTime(const QDateTime & dateTime) const
+{
+	KTimeZone local = KSystemTimeZones::local();
+	if( m_timeZone.isValid() && local.name() != m_timeZone.name() )
+		return m_timeZone.convert(local, dateTime);
+	return dateTime;
 }
 
 bool
@@ -416,15 +451,22 @@ CityWeather::isDayTime( const YawpDay * day ) const
 	if( !day || !day->sunset().isValid() || !day->sunrise().isValid() )
 		return true;
 
-	QDateTime currentTime( localTime() );
+	QDateTime currentTime;
+	if( observationPeriode().isValid() )
+		currentTime = observationPeriode();
+	else
+		currentTime = localTime();
+	
 	QDateTime sunrise( currentTime.date(), day->sunrise() );
 	QDateTime sunset( currentTime.date(), day->sunset() );
 	
-/*	dTracing() << "current Time: " << currentTime;
-	dTracing() << "sunrise: " << sunrise;
-	dTracing() << "sunset: " << sunset;
-*/
-	return (currentTime > sunrise && currentTime  < sunset);
+	bool bReturn = (currentTime > sunrise && currentTime  < sunset);
+
+	dTracing() << "City: " << m_sLocalizedCity <<"   current Time:" << currentTime
+	           << "   sunrise:" << sunrise << "   sunset:" << sunset
+	           << "   daytime:" << bReturn;
+
+	return bReturn;
 }
 
 void
@@ -471,6 +513,10 @@ CityWeather::debug_PrintCityWeather( const CityWeather & cityInfo )
 				.arg(sPrefix).arg(weather.windSpeed()).toUtf8().constData();
 			dDebug() << QString("   %1windDirection = %2")
 				.arg(sPrefix).arg(weather.windDirection()).toUtf8().constData();
+
+			dDebug() << QString("  %1property text lines = %2")
+				.arg(sPrefix).arg(weather.propertyTextLines().count()).toUtf8().constData();
+			  
 			dDebug();
 		}
 	}
