@@ -157,6 +157,9 @@ function usage
   echo "              suppressed; loglevels with increasing priority:"
   echo "              [Tracing,Debug,Info,Warning,Critical,Error]"
   echo "   -u        build unittest directory"
+  echo "   -j CORES  Number of CPUs to use for compilation"
+  echo "              Default: 2 cores on Dual core CPU"
+  echo "                       (CPU cores - 1) for Multi-cores CPU (>2)"
 }
 
 ##############################################################################################################
@@ -167,7 +170,7 @@ UNITTESTS=
 LOGFILE="-DDEBUG_LOGFILE=/tmp/yawp.log"
 LOGLEVEL="-DDEBUG_LOGLEVEL=Debug"
 
-while getopts "hduf:l:" OPT
+while getopts "hduf:l:j:" OPT
 do
 	case $OPT in
 	d) DEBUG="-DCMAKE_BUILD_TYPE=Debug" ;;
@@ -183,6 +186,7 @@ do
 		*)  echo "$0: invalid argument for option -- l"
 			usage ; exit ;;
 		esac ;;
+	j) JOB_COUNT=$OPTARG ;;
 	?) usage ; exit ;;
 	esac
 
@@ -192,7 +196,8 @@ echo "DEBUG: $DEBUG"
 echo "UNITTESTS: $UNITTESTS"
 echo "LOGLEVEL: $LOGLEVEL"
 echo "LOGFILE: $LOGFILE"
-
+echo
+echo "Prepare build directory..."
 rm --recursive --force build CMakeFiles CMakeTmp CMakeCache.txt cmake_install.cmake cmake_uninstall.cmake CTestTestfile.cmake Makefile
 
 if [ ! -d build  ]; then
@@ -205,6 +210,8 @@ if [ $ret -ne 0 ]; then
 	exit
 fi
 
+echo 
+echo "Run cmake..."
 cd build
 cmake -DCMAKE_INSTALL_PREFIX=`kde4-config --prefix` $DEBUG $UNITTESTS $LOGFILE $LOGLEVEL ..
 
@@ -214,8 +221,35 @@ if [ $ret -ne 0 ]; then
 	exit
 fi
 
+echo
+echo "Run make clean..."
 make clean
-make
+
+echo
+echo "Compile..."
+if [ -z "$JOB_COUNT" ]; then
+	## Try to determine the number of processor-cores.
+	JOB_COUNT=1
+	if [ -f /proc/cpuinfo ]; then
+		JOB_COUNT=`grep ^processor /proc/cpuinfo | wc -l`
+	fi
+
+	## Just make sure, we have a valid number (e.g.: in case we have no rights to read the processor cores).
+	## Can this happen??
+	if [ $JOB_COUNT -eq 0 ]; then
+		JOB_COUNT=1
+	fi
+
+	## Use almost all processor cores, when we have more than two cores.
+	## We are not too selfish and leave at least one core for other programs, when user has more than two cores :)
+	## Just to optimise the compile time and do not let the user wait to long for new applet.
+	if [ $JOB_COUNT -gt 2 ]; then
+		let "JOB_COUNT = ($JOB_COUNT - 1)"
+	fi
+fi
+
+echo -e $MESSAGE"Going to use $JOB_COUNT cores to compile package yaWP."$NORMALTEXT
+make -j $JOB_COUNT
 
 ret=$?
 if [ $ret -ne 0 ]; then
