@@ -40,6 +40,7 @@
 //--- LOCAL ---
 #include "../config.h"
 #include "ion_accuweather.h"
+#include "accuweather_configloader.h"
 #include "logger/streamlogger.h"
 
 //--- QT4 ---
@@ -64,6 +65,10 @@ static const char vWeekdays [7][4] = {"Mon", "Tue", "Wed", "Thu", "Fri", "Sat",
 
 struct AccuWeatherIon::Private
 {
+	QMutex                            syncMutex;
+	AccuWeatherConfigMap    *         configMap;
+	AccuWeatherConfigLoader *         currentConfigLoader;
+  
 	QMap<QString, ConditionIcons>     vConditionList;
 
 	QHash<QString, KJob *>            vActiveJobs;
@@ -88,6 +93,8 @@ AccuWeatherIon::AccuWeatherIon( QObject * parent, const QVariantList & args )
 	  d( new Private )
 {
 	Q_UNUSED(args)
+	d->currentConfigLoader = 0;
+	d->configMap = 0;
 	
 	dInfo() << "AccuWeatherIon" << YAWP_VERSION_STRING << "compiled at" << __DATE__ << __TIME__ << "for KDE" << KDE_VERSION_STRING;
 
@@ -143,15 +150,72 @@ AccuWeatherIon::AccuWeatherIon( QObject * parent, const QVariantList & args )
 
 AccuWeatherIon::~AccuWeatherIon()
 {
+	dStartFunct();
+	
 	cleanup();
+	
+	// We can not use QMutexLocker here, because we will delete d, which contains d->syncMutex!!!
+	//
+	d->syncMutex.lock();
+	if( d->currentConfigLoader != 0 )
+	{
+		if( d->currentConfigLoader->isRunning() )
+			d->currentConfigLoader->wait();
+		
+		delete d->currentConfigLoader;
+		d->currentConfigLoader = 0;
+	}
+	if( d->configMap != 0 )
+		delete d->configMap;
+	d->syncMutex.unlock();
+	
 	delete d;
+	
+	dEndFunct();
 }
 
 void
 AccuWeatherIon::init()
 {
-//	setMinimumPollingInterval( 2*60*1000 );	// wait at least 2 minutes to update the source
+	dStartFunct();
+	
+	bool bInitialized = true;
+	
+	d->syncMutex.lock();
+	if( d->currentConfigLoader == 0 && d->configMap == 0 )
+	{
+		bInitialized = false;
+		
+		d->currentConfigLoader = new AccuWeatherConfigLoader();
+		connect(d->currentConfigLoader, SIGNAL(finished()), this, SLOT(slotConfigLoaderFinished()));
+	
+		d->currentConfigLoader->start(QThread::LowPriority);
+	}
+	d->syncMutex.unlock();
+	
+	if (bInitialized)
+		setInitialized(true);
+	
+	dEndFunct();
+}
+
+void
+AccuWeatherIon::slotConfigLoaderFinished()
+{
+	dStartFunct();
+	
+	d->syncMutex.lock();
+	if( d->currentConfigLoader != 0 )
+	{
+		d->configMap = d->currentConfigLoader->configMap();
+		delete d->currentConfigLoader;
+		d->currentConfigLoader = 0;
+	}
+	d->syncMutex.unlock();
+	
 	setInitialized(true);
+	
+	dEndFunct();
 }
 
 bool
@@ -460,7 +524,8 @@ AccuWeatherIon::getWeatherXmlData( const QString & location, const QString & loc
 		d->vObservationJobs.insert( pJob, pXmlData);
 		d->vActiveJobs.insert( QString("%1|%2").arg(locationCode).arg(ActionWeather), pJob );
 		
-		connectWithImageData( pXmlData->imageUrl );
+		if( !pXmlData->imageUrl.isEmpty() )
+			connectWithImageData( pXmlData->imageUrl );
 
 		connect( pJob, SIGNAL(data(KIO::Job *, const QByteArray &)), this,
 			SLOT(slotDataArrived(KIO::Job *, const QByteArray &)) );
@@ -514,7 +579,7 @@ AccuWeatherIon::slotJobFinished( KJob * pJob )
 		if( pImageData )
 			pImageData->iLocationCounter -= 1;
 		else
-			dWarning() << pXmlData->sSource << "xml-job has not image-data!";
+			dWarning() << pXmlData->sSource << "xml-job has no image-data!";
 	}
 	else
 	{
@@ -1019,8 +1084,53 @@ AccuWeatherIon::updateSun( const QString & source,
 QByteArray
 AccuWeatherIon::getImageUrl( const QString & sLocationCode ) const
 {
-	QByteArray sUrl;
+	QByteArray sUrl = "";
+	
+	QStringList lst = sLocationCode.split('|',QString::SkipEmptyParts);
+	QString firstKey;
+	QString secondKey;
+	QString thirdKey;
+	
+	if( lst.count() > 2 )
+	{
+		if( lst.count() >= 3 )
+		{
+			QString locationCode = lst[2].left(4);
+			firstKey = AccuWeatherConfigLoader::createLocationCode(lst[0], lst[1], locationCode);
+		}
+		secondKey = AccuWeatherConfigLoader::createLocationCode(lst[0], lst[1]);
+		thirdKey = AccuWeatherConfigLoader::createLocationCode(lst[0]);
+	}
+	else if( sLocationCode.length() > 2 )	// we assume it is a US country
+	{
+		QString areaCode = "US";
+		QString countryCode = sLocationCode.left(2);
+		QString locationCode = "";
+		
+		if(sLocationCode.length() >= 4)
+			locationCode = sLocationCode.mid(2,2);
+		
+		firstKey = AccuWeatherConfigLoader::createLocationCode(areaCode, countryCode, locationCode);
+		secondKey = AccuWeatherConfigLoader::createLocationCode(areaCode, countryCode);
+		thirdKey = AccuWeatherConfigLoader::createLocationCode(areaCode);
+	}
+	
+	d->syncMutex.lock();
+	if( d->configMap != 0 )	// config map has been loaded and it is save to exit the data
+	{
+		if( !firstKey.isEmpty() && d->configMap->contains(firstKey) )
+			sUrl = d->configMap->value(firstKey);
+		else if( !secondKey.isEmpty() && d->configMap->contains(secondKey) )
+			sUrl = d->configMap->value(secondKey);
+		else if( !thirdKey.isEmpty() && d->configMap->contains(thirdKey) )
+			sUrl = d->configMap->value(thirdKey);
+	}
+	d->syncMutex.unlock();
 
+	dDebug() << "Url for" << sLocationCode << sUrl;
+	return sUrl;
+
+/*
 	//--- city of the united states ---
 	if( sLocationCode.at(3) != '|' )
 		sUrl = QByteArray("http://sirocco.accuweather.com/sat_mosaic_400x300_public/EI/iseun.jpg");
@@ -1074,7 +1184,7 @@ AccuWeatherIon::getImageUrl( const QString & sLocationCode ) const
 				sUrl = QByteArray("http://sirocco.accuweather.com/sat_mosaic_400x300_public/IR/isafrs.jpg");
 		}
 	}
-	return sUrl;
+*/
 }
 
 
