@@ -1045,17 +1045,17 @@ WundergroundIon::Private::parseForecastDay( QXmlStreamReader & xml,
 
 	XmlForecastDay * pDay = new XmlForecastDay;
 	
-	short iLevel(1);	// we have parsed the start tag already, and decided to call this function!!!
-	short iPeriod(0);
+	short iLevel = 1;	// we have parsed the start tag already, and decided to call this function!!!
+//	short iPeriod = 0;
 	
 	while( !xml.atEnd() )
 	{
 		xml.readNext();
 		if( xml.isStartElement() )
 		{
-			if( xml.name().compare("period") == 0 )
-				iPeriod = xml.readElementText().toInt();
-			else if( xml.name().compare("weekday") == 0 )
+//			if( xml.name().compare("period") == 0 )
+//				iPeriod = xml.readElementText().toInt();
+			if( xml.name().compare("weekday") == 0 )
 				pDay->sDayName = i18n(xml.readElementText().left(3).toUtf8().constData());
 			else if( xml.name().compare("tz_long") == 0 )
 				sTimeZone = xml.readElementText();
